package
Version:
v0.0.0-...-6ec6b3a
Opens a new window with list of versions in this module.
Published: Nov 26, 2019
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type MonesignNode struct {
Identity *peer.Peer
PeerBook *peerbook.PeerBook
Storage *storage.Storage
Network *netmux.Netux
Routing *routing.Routing
Bitswap *bitswap.Bitswap
Blocks *blocks.BlockService
Resolver *resolver.PathResolver
Namesys *namesys.Namesys
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.